@@ -6,6 +6,10 @@
 #' 
 #' @return invisible.
 cap_url <- function(x) {
-  stopifnot("url exceeds 2000 characters, please try a simpler query" = nchar(as.character(x)) <= 2000)
+  
+  stopifnot(
+    "url exceeds 2000 characters, please try a simpler query." = nchar(as.character(x)) <= 2000
+    )
+  
   return(invisible())
 }
