@@ -24,7 +24,7 @@ package_metadata <- function(package) {
   
   res <- httr::GET(query)
   
-  httr::stop_for_status(res)
+  detect_error(res)
   
   con <- httr::content(res)
   
